==> Task-BeLike-MSCHOUT-1.111500.tar.gz: Task-BeLike-MSCHOUT-1.111500/lib/Task/BeLike/MSCHOUT.pm <==
package Task::BeLike::MSCHOUT;
BEGIN {
  $Task::BeLike::MSCHOUT::VERSION = '1.111500';
}

use strict;
use warnings;

# ABSTRACT: be more like MSCHOUT -- use the modules he does!


__END__
=pod

=head1 NAME

Task::BeLike::MSCHOUT - be more like MSCHOUT -- use the modules he does!

=head1 VERSION

version 1.111500

=head1 TASK CONTENTS

=head2 Useful Command-Line Tools

=head3 L<App::Ack> 1.82

Version 1.82 required because: a working --pager

=head3 L<App::Nopaste> 0.28

Version 0.28 required because: Gist support via Gist API

=head3 L<App::cpanminus>

=head3 L<App::cpanoutdated>

=head3 L<Perl::Tidy>

=head3 L<Vimana>

=head2 Useful CPAN Modules

=head3 L<Archive::Zip>

=head3 L<BackPAN::Index>

=head3 L<LWP::Protocol::https>

=head3 L<CSS::Minifier>

=head3 L<CSS::Minifier::XS>

=head3 L<DBD::SQLite>

=head3 L<DBI>

=head3 L<Dist::Zilla::Plugin::Twitter>

=head3 L<Dist::Zilla::PluginBundle::MSCHOUT>

=head3 L<Dist::Zilla::PluginBundle::RJBS>

=head3 L<Gravatar::URL>

=head3 L<IO::Socket::SSL>

=head3 L<IPC::System::Simple>

=head3 L<JavaScript::Minifier>

=head3 L<JavaScript::Minifier::XS>

=head3 L<Modern::Perl>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<SQL::Beautify>

=head3 L<String::Truncate>

=head3 L<Template::Test>

=head3 L<Test::Pod::Coverage>

1;

=head1 AUTHOR

Michael Schout <mschout@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Michael Schout.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 SOURCE

The development version is on github at L<http://github.com/mschout/task-belike-mschout>
and may be cloned from L<git://github.com/mschout/task-belike-mschout.git>

=head1 BUGS

Please report any bugs or feature requests to bug-task-belike-mschout@rt.cpan.org or through the web interface at:
 http://rt.cpan.org/Public/Dist/Display.html?Name=Task-BeLike-MSCHOUT

=cut

==> Task-BeLike-MSCHOUT-1.130940.tar.gz: Task-BeLike-MSCHOUT-1.130940/lib/Task/BeLike/MSCHOUT.pm <==
package Task::BeLike::MSCHOUT;
{
  $Task::BeLike::MSCHOUT::VERSION = '1.130940';
}

use strict;
use warnings;

# ABSTRACT: be more like MSCHOUT -- use the modules he does!

__END__

=pod

=head1 NAME

Task::BeLike::MSCHOUT - be more like MSCHOUT -- use the modules he does!

=head1 VERSION

version 1.130940

=head1 TASK CONTENTS

=head2 Useful Command-Line Tools

=head3 L<App::Ack> 1.82

Version 1.82 required because: a working --pager

=head3 L<App::Nopaste> 0.28

Version 0.28 required because: Gist support via Gist API

=head3 L<App::cpanminus>

=head3 L<App::cpanoutdated>

=head3 L<Perl::Tidy>

=head3 L<Vimana>

=head2 Useful CPAN Modules

=head3 L<Archive::Zip>

=head3 L<BackPAN::Index>

=head3 L<CSS::Minifier>

=head3 L<CSS::Minifier::XS>

=head3 L<DBD::SQLite>

=head3 L<DBI>

=head3 L<Devel::NYTProf>

=head3 L<Dist::Zilla::Plugin::GitHub>

=head3 L<Dist::Zilla::Plugin::Twitter>

=head3 L<Dist::Zilla::PluginBundle::MSCHOUT>

=head3 L<File::Find::Rule>

=head3 L<Git::CPAN::Patch>

=head3 L<Gravatar::URL>

=head3 L<IO::Socket::SSL>

=head3 L<IPC::System::Simple>

=head3 L<JavaScript::Minifier>

=head3 L<JavaScript::Minifier::XS>

=head3 L<LWP>

=head3 L<LWP::Protocol::https>

=head3 L<List::MoreUtils>

=head3 L<Method::Signatures>

=head3 L<Modern::Perl>

=head3 L<Moo>

=head3 L<Moose>

=head3 L<Moose::Autobox>

=head3 L<MooseX::App>

=head3 L<MooseX::Method::Signatures>

=head3 L<Mouse>

=head3 L<Perl6::Junction>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<SQL::Beautify>

=head3 L<String::Truncate>

=head3 L<Template::Test>

=head3 L<Test::Pod::Coverage>

=head3 L<TryCatch>

=head3 L<URI>

1;

=head1 AUTHOR

Michael Schout <mschout@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Michael Schout.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 SOURCE

The development version is on github at L<http://github.com/mschout/task-belike-mschout>
and may be cloned from L<git://github.com/mschout/task-belike-mschout.git>

=head1 BUGS

Please report any bugs or feature requests to bug-task-belike-mschout@rt.cpan.org or through the web interface at:
 http://rt.cpan.org/Public/Dist/Display.html?Name=Task-BeLike-MSCHOUT

=cut
